pub struct Span {
pub n: usize,
pub start_line_num: usize,
pub validity: u8,
}Fields
n: usizeNumber of lines in this span. Units are visual lines in the current state of the view.
start_line_num: usizeStarting line number. Units are visual lines in the front end’s current cache state (i.e. the last one rendered). Note: this is irrelevant if validity is 0.
validity: u8Validity of lines in this span, consisting of the above constants or’ed.