Movement

Enum Movement 

pub enum Movement {
Show 17 variants Left, Right, LeftWord, RightWord, LeftOfLine, RightOfLine, Up, Down, UpPage, DownPage, UpExactPosition, DownExactPosition, StartOfParagraph, EndOfParagraph, EndOfParagraphKill, StartOfDocument, EndOfDocument,
}
The specification of a movement.

Variants



Left

Move to the left by one grapheme cluster.



Right

Move to the right by one grapheme cluster.



LeftWord

Move to the left by one word.



RightWord

Move to the right by one word.



LeftOfLine

Move to left end of visible line.



RightOfLine

Move to right end of visible line.



Up

Move up one visible line.



Down

Move down one visible line.



UpPage

Move up one viewport height.



DownPage

Move down one viewport height.



UpExactPosition

Move up to the next line that can preserve the cursor position.



DownExactPosition

Move down to the next line that can preserve the cursor position.



StartOfParagraph

Move to the start of the text line.



EndOfParagraph

Move to the end of the text line.



EndOfParagraphKill

Move to the end of the text line, or next line if already at end.



StartOfDocument

Move to the start of the document.



EndOfDocument

Move to the end of the document