pub trait WidthMeasure {
// Required method
fn measure_width(
&self,
request: &[WidthReq],
) -> Result<WidthResponse, Error>;
}Expand description
A trait for types that provide width measurement. In the general case this will be provided by the frontend, but alternative implementations might be provided for faster measurement of ‘fixed-width’ fonts, or for testing.
Required Methods
fn measure_width(&self, request: &[WidthReq]) -> Result<WidthResponse, Error>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".